==> haskell-quickcheck-instances-0.3.30-281-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.30
visibility:           public
id:                   quickcheck-instances-0.3.30-KxOKVg00O1KGVtAspS1Meb
key:                  quickcheck-instances-0.3.30-KxOKVg00O1KGVtAspS1Meb
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  59ce6d19cf782b5026d3f2fb24680ecb
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.30
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.30-KxOKVg00O1KGVtAspS1Meb
depends:
    OneTuple-0.4.2-H2hq3WX7vAYH5Mde32s1b7
    QuickCheck-2.14.3-3S3WOBL6rHa3L0CMYI1WVh array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-1RHeXy1S6Rm5Spie3OUbmD containers-0.6.7
    data-fix-0.3.4-9JiznarwTn78ZcCXXj3YzS
    hashable-1.4.4.0-85lkkmOSRZHDIzkr9EkKNp
    integer-logarithms-1.0.4-6KzhoYw0JwIFtvBwh4KbEB
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9
    primitive-0.9.1.0-KawCla5BA6F2MLtBZRS1Dh
    scientific-0.3.8.0-HUqAf4XaF5T5GawpMI5GwR
    splitmix-0.1.1-7mLkDNhh9jS1RKDcBBOeZJ
    strict-0.5-3YqyrbNmr9gBQeoCoaFr88
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-short-0.1.6-fDzHeUBKE6ANI3Oi274D7
    these-1.2.1-FsoNf3khtpBE0WQeyNf7Ak time-1.12.2
    time-compat-1.9.6.1-9iw1ctcwRHN8OsnPh4FEOm transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-Cw2Ec4BgC4sInKE4e5RLSk
    uuid-types-1.0.6-9HT5d1aFDJVGckTkPRv4GI
    vector-0.13.2.0-3jopdCx3MMLHVSrvHoDH9i

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.31-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.31
visibility:           public
id:                   quickcheck-instances-0.3.31-22AGB02LYpCH5a9AUPkQ93
key:                  quickcheck-instances-0.3.31-22AGB02LYpCH5a9AUPkQ93
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  358de542927de82dd8c9b2782a984ae1
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
library-dirs:         /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/quickcheck-instances-0.3.31
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.31-22AGB02LYpCH5a9AUPkQ93
depends:
    OneTuple-0.4.2-IOFILawEOp4I9m5GnYdL6z
    QuickCheck-2.14.3-FFJcwBneLUJ2oV3g9w1Xpr array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-ExBJBOcZyg68qqvcd4Xhlk containers-0.6.7
    data-fix-0.3.4-9UPRtnsTssjCCE5AusFWty
    hashable-1.4.4.0-GlHmxadJMPDAuB7eaK8Jlw
    integer-logarithms-1.0.4-Ay6UiiHv1U95CSWqAPJWre
    old-time-1.1.0.4-7kNg8VzooGoExH4yeT9sv9
    primitive-0.9.1.0-IzoEy6gcvXy7FAbkwCq547
    scientific-0.3.8.0-K87kS3pXvmIAS7ph5w5sEk
    splitmix-0.1.1-GgvlaogFfyDBcF11tSVIzR
    strict-0.5-ETOhAAhtg64iIOUslgq1c
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    text-short-0.1.6-EmCCKFN3VAc7oc22bHjFED
    these-1.2.1-8DoYO1sOF1M5rJ31228gcD
    time-compat-1.9.6.1-CwoAla4DecgKgr9qeVmJJW transformers-0.5.6.2
    unordered-containers-0.2.20-8II8ZaVgh7AI0VqHCtkj9z
    uuid-types-1.0.6-HMh9IaktRPeJGhUhGPIqPK
    vector-0.13.2.0-GVofNlblW9iFyKfTum1VeM

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
